## Generating the Documentation

This project uses [mkdocs](https://www.mkdocs.org/) along with [mkdocstrings](https://mkdocstrings.github.io/) to generate
the documentation for the helper package accompanying the computer exercises. To build the documentation, run the
following command:

```bash
mkdocs build  # The output can be found under /public
```

If you want to preview the documentation locally (while working on it), you can run the following command:

```bash
mkdocs serve
```
